Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1554)

Unified Diff: content/common/origin_trials/trial_token.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/cross_site_document_classifier.cc ('k') | content/common/origin_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/origin_trials/trial_token.cc
diff --git a/content/common/origin_trials/trial_token.cc b/content/common/origin_trials/trial_token.cc
index c8f8cdda617d92aed5e06a15c310dcdbfeea8ea2..73efec1c18eaa56db9eee0c7c23babe3871bb917 100644
--- a/content/common/origin_trials/trial_token.cc
+++ b/content/common/origin_trials/trial_token.cc
@@ -158,9 +158,9 @@ std::unique_ptr<TrialToken> TrialToken::Parse(
datadict->GetString("feature", &feature_name);
datadict->GetInteger("expiry", &expiry_timestamp);
// Ensure that the origin is a valid (non-unique) origin URL.
url::Origin origin = url::Origin(GURL(origin_string));
- if (origin.unique()) {
+ if (origin.opaque()) {
return nullptr;
}
« no previous file with comments | « content/common/cross_site_document_classifier.cc ('k') | content/common/origin_util.cc » ('j') | no next file with comments »
@@ -158,9 +158,9 @@ std::unique_ptr<TrialToken> TrialToken::Parse(
datadict->GetString("feature", &feature_name);
datadict->GetInteger("expiry", &expiry_timestamp);
- // Ensure that the origin is a valid (non-unique) origin URL.
+ // Ensure that the origin is a valid (non-opaque) origin URL.
url::Origin origin = url::Origin(GURL(origin_string));

Powered by Google App Engine
This is Rietveld 408576698